@@ -1,6 +1,7 @@
 import argparse
 import pytorch_lightning as pl
 import torch
+from typing import Dict, Any
 
 from transformers.optimization import get_linear_schedule_with_warmup
 
@@ -117,3 +118,18 @@ class BaseLitModel(pl.LightningModule):
                 'frequency': 1,
             }
         }
+
+    @pl.utilities.rank_zero_only
+    def on_save_checkpoint(self, checkpoint: Dict[str, Any], filepath=None) -> None:
+        # if filepath is not None:
+        #     save_path = filepath[:-5]
+        # else:
+        #     save_path = self.output_dir.joinpath("checkpoint-hello")
+        save_path = filepath #self.output_dir.joinpath("checkpoint-curr_best")
+        print('the suggested save_path is {}, saving to {}'.format(filepath, save_path))
+
+        # self.model.config.save_step = self.step_count
+        assert hasattr(self.model, "save_pretrained"), "Must use Huggingface's transformers models"
+        self.model.save_pretrained(save_path)
+        self.tokenizer.save_pretrained(save_path)
+        print('SAVING TO checkpoint {}'.format(save_path))
\ No newline at end of file
